@@ -23,6 +23,13 @@ import qualified KATXTS
 import qualified KATGCM
 import qualified KATOCB3
 
+instance Show AES.AES where
+    show _ = "AES"
+instance Arbitrary AES.AESIV where
+    arbitrary = AES.aesIV_ . B.pack <$> replicateM 16 arbitrary
+instance Arbitrary AES.AES where
+    arbitrary = AES.initAES . B.pack <$> replicateM 16 arbitrary
+
 toKatECB (k,p,c) = KAT_ECB { ecbKey = k, ecbPlaintext = p, ecbCiphertext = c }
 toKatCBC (k,iv,p,c) = KAT_CBC { cbcKey = k, cbcIV = iv, cbcPlaintext = p, cbcCiphertext = c }
 toKatXTS (k1,k2,iv,p,_,c) = KAT_XTS { xtsKey1 = k1, xtsKey2 = k2, xtsIV = iv, xtsPlaintext = p, xtsCiphertext = c }
@@ -62,10 +69,16 @@ kats256 = defaultKATs
     { kat_ECB  = map toKatECB KATECB.vectors_aes256_enc
     , kat_CBC  = map toKatCBC KATCBC.vectors_aes256_enc
     , kat_XTS  = map toKatXTS KATXTS.vectors_aes256_enc
+    , kat_AEAD = map toKatGCM KATGCM.vectors_aes256_enc
     }
 
 main = defaultMain
     [ testBlockCipher kats128 (undefined :: AES.AES128)
     , testBlockCipher kats192 (undefined :: AES.AES192)
     , testBlockCipher kats256 (undefined :: AES.AES256)
+    , testProperty "genCtr" $ \(key, iv1) ->
+        let (bs1, iv2)    = AES.genCounter key iv1 32
+            (bs2, iv3)    = AES.genCounter key iv2 32
+            (bsAll, iv3') = AES.genCounter key iv1 64
+         in (B.concat [bs1,bs2] == bsAll && iv3 == iv3')
     ]
