@@ -169,7 +169,7 @@ typedef void (*block_f)(aes_block *output, aes_key *key, aes_block *input);
 #define aes_decrypt_block(o,k,i) \
 	(((block_f) (branch_table[DECRYPT_BLOCK_128 + k->strength]))(o,k,i))
 #else
-#define GET_INIT(strenght) aes_generic_init
+#define GET_INIT(strength) aes_generic_init
 #define GET_ECB_ENCRYPT(strength) aes_generic_encrypt_ecb
 #define GET_ECB_DECRYPT(strength) aes_generic_decrypt_ecb
 #define GET_CBC_ENCRYPT(strength) aes_generic_encrypt_cbc
@@ -262,7 +262,7 @@ void aes_decrypt_cbc(aes_block *output, aes_key *key, aes_block *iv, aes_block *
 	d(output, key, iv, input, nb_blocks);
 }
 
-void aes_gen_ctr(aes_block *output, aes_key *key, aes_block *iv, uint32_t nb_blocks)
+void aes_gen_ctr(aes_block *output, aes_key *key, const aes_block *iv, uint32_t nb_blocks)
 {
 	aes_block block;
 
@@ -274,6 +274,21 @@ void aes_gen_ctr(aes_block *output, aes_key *key, aes_block *iv, uint32_t nb_blo
 	}
 }
 
+void aes_gen_ctr_cont(aes_block *output, aes_key *key, aes_block *iv, uint32_t nb_blocks)
+{
+	aes_block block;
+
+	/* preload IV in block */
+	block128_copy(&block, iv);
+
+	for ( ; nb_blocks-- > 0; output++, block128_inc_be(&block)) {
+		aes_encrypt_block(output, key, &block);
+	}
+
+	/* copy back the IV */
+	block128_copy(iv, &block);
+}
+
 void aes_encrypt_ctr(uint8_t *output, aes_key *key, aes_block *iv, uint8_t *input, uint32_t len)
 {
 	ctr_f e = GET_CTR_ENCRYPT(key->strength);
@@ -674,8 +689,8 @@ void aes_generic_gcm_decrypt(uint8_t *output, aes_gcm *gcm, aes_key *key, uint8_
 	}
 }
 
-static int ocb_generic_crypt(uint8_t *output, aes_ocb *ocb, aes_key *key,
-                             uint8_t *input, uint32_t length, int encrypt)
+static void ocb_generic_crypt(uint8_t *output, aes_ocb *ocb, aes_key *key,
+                              uint8_t *input, uint32_t length, int encrypt)
 {
 	block128 tmp, pad;
 	unsigned int i;
