@@ -89,7 +89,7 @@ static uint8_t Rcon[] = {
 };
 
 #define G(a,b,c,d,e,f) { a,b,c,d,e,f }
-uint8_t gmtab[256][6] =
+static uint8_t gmtab[256][6] =
 {
 	G(0x00, 0x00, 0x00, 0x00, 0x00, 0x00), G(0x02, 0x03, 0x09, 0x0b, 0x0d, 0x0e),
 	G(0x04, 0x06, 0x12, 0x16, 0x1a, 0x1c), G(0x06, 0x05, 0x1b, 0x1d, 0x17, 0x12),
